==> kdepim-addons-16.08.1.tar.xz: kdepim-addons-16.08.1/kaddressbook/plugins/searchduplicates/searchduplicatesplugininterface.h <==
/*
   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef SEARCHDUPLICATESPLUGININTERFACE_H
#define SEARCHDUPLICATESPLUGININTERFACE_H

#include <pimcommon/genericplugininterface.h>

class SearchDuplicatesPluginInterface : public PimCommon::GenericPluginInterface
{
public:
    explicit SearchDuplicatesPluginInterface(QObject *parent = Q_NULLPTR);
    ~SearchDuplicatesPluginInterface();

    void exec() Q_DECL_OVERRIDE;
    void createAction(KActionCollection *ac) Q_DECL_OVERRIDE;
    PimCommon::GenericPluginInterface::RequireTypes requires() const Q_DECL_OVERRIDE;
    void setItems(const Akonadi::Item::List &items) Q_DECL_OVERRIDE;

private:
    void slotActivated();
    Akonadi::Item::List mListItems;
};

#endif // SEARCHDUPLICATESPLUGININTERFACE_H

==> kdepim-addons-17.04.1.tar.xz: kdepim-addons-17.04.1/kaddressbook/plugins/searchduplicates/searchduplicatesplugininterface.h <==
/*
   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef SEARCHDUPLICATESPLUGININTERFACE_H
#define SEARCHDUPLICATESPLUGININTERFACE_H

#include <PimCommonAkonadi/GenericPluginInterface>

class SearchDuplicatesPluginInterface : public PimCommon::GenericPluginInterface
{
public:
    explicit SearchDuplicatesPluginInterface(QObject *parent = nullptr);
    ~SearchDuplicatesPluginInterface();

    void exec() Q_DECL_OVERRIDE;
    void createAction(KActionCollection *ac) Q_DECL_OVERRIDE;
    PimCommon::GenericPluginInterface::RequireTypes requires() const Q_DECL_OVERRIDE;
    void setItems(const Akonadi::Item::List &items) Q_DECL_OVERRIDE;

private:
    void slotActivated();
    Akonadi::Item::List mListItems;
};

#endif // SEARCHDUPLICATESPLUGININTERFACE_H
